# xdart
X-ray Data Analysis in Real Time

# Installation
It is recommended to use conda. Run "conda env create -f xdart_env.yml", followed by "conda activate xdart_env". The program can then be run by calling xdart_main.py.
